# eric7.Tasks.TaskFilter

Module implementing a class to store task data.

### Global Attributes

None

### Classes

TaskFilter | Class implementing a filter for tasks.

### Functions

None

## TaskFilter

Class implementing a filter for tasks.

### Derived from

None

### Class Attributes

None

### Class Methods

None

### Methods

TaskFilter | Constructor
hasActiveFilter | Public method to check for active filters.
setActive | Public method to activate the filter.
setFileNameFilter | Public method to set the filename filter.
setPrioritiesFilter | Public method to set the priorities filter.
setScopeFilter | Public method to set the scope filter.
setStatusFilter | Public method to set the status filter.
setSummaryFilter | Public method to set the description filter.
setTypeFilter | Public method to set the type filter.
showTask | Public method to check, if a task should be shown.

### Static Methods

None

#### TaskFilter (Constructor)

TaskFilter()

Constructor

#### TaskFilter.hasActiveFilter

hasActiveFilter()

Public method to check for active filters.

Return:
  flag indicating an active filter was found (boolean)

#### TaskFilter.setActive

setActive(enabled)

Public method to activate the filter.

enabled
  flag indicating the activation state (boolean)

#### TaskFilter.setFileNameFilter

setFileNameFilter(filterStr)

Public method to set the filename filter.

filterStr
  a wildcard expression for the filename filter to set (string) or None

#### TaskFilter.setPrioritiesFilter

setPrioritiesFilter(priorities)

Public method to set the priorities filter.

priorities (list of TaskPriority or None)
  list of task priorities or None

#### TaskFilter.setScopeFilter

setScopeFilter(scope)

Public method to set the scope filter.

scope
  flag indicating a project task (boolean) or None

#### TaskFilter.setStatusFilter

setStatusFilter(status)

Public method to set the status filter.

status
  flag indicating a completed task (boolean) or None

#### TaskFilter.setSummaryFilter

setSummaryFilter(filterStr)

Public method to set the description filter.

filterStr
  a regular expression for the description filter to set (string) or None

#### TaskFilter.setTypeFilter

setTypeFilter(taskType)

Public method to set the type filter.

taskType (TaskType)
  type of the task

#### TaskFilter.showTask

showTask(task)

Public method to check, if a task should be shown.

task
  reference to the task object to check (Task)

Return:
  flag indicating whether the task should be shown (boolean)

Up